@@ -10,32 +10,26 @@ import pexpect, time
 # echo "alias config='/usr/bin/git --git-dir=$HOME/.cfg/ --work-tree=$HOME'" >> $HOME/.bashrc
 
 def runccore(*args):
-    click.echo(click.style('.g.  ', fg='cyan'),nl=False)
-    click.echo(click.style(" ".join(args), fg='bright_white'))
-    click.echo(click.style('.g.  ', fg='cyan'),nl=True)
+    click.echo(click.style('.ds. ', fg='magenta'),nl=False)
+    click.echo(click.style(" ".join(args), fg='green'))
+    click.echo(click.style('.git. ', fg='cyan'),nl=True)
 
     p = pexpect.spawn(" ".join(args))
-    lines = p.readlines()
-    for l in lines:
-        click.echo(click.style('.g.  ', fg='cyan'),nl=False)
+    for l in p:
+        click.echo(click.style('.git. ', fg='cyan'),nl=False)
         click.echo(l,nl=False)
-    timeout=30
+    timeout=10
     while p.isalive() and timeout>0:
         click.echo(click.style('.', fg='cyan'))
         time.sleep(1)
         timeout-=1
     p.close()
-    click.echo(click.style('...', fg='cyan'),nl=True)
+    click.echo(click.style('', fg='magenta'),nl=True)
 
     return p.exitstatus
 
-    retval = subprocess.run( list(args), check=False, stdout=subprocess.PIPE, stderr=subprocess.STDOUT, universal_newlines=True)
-    if retval.stdout != "":
-        [click.echo( click.style(' .git.     ', fg='cyan') + l ) for l in retval.stdout.split("\n")]
-    return retval
-
 def run(*args):
-    return runccore( 'git',"--git-dir=%s/.dotstrap" % os.environ["HOME"], "--work-tree=%s" % os.environ["HOME"], *args )
+    return runccore( 'git', "--no-pager", "--git-dir=%s/.dotstrap" % os.environ["HOME"], "--work-tree=%s" % os.environ["HOME"], *args )
 
 def echo(s):
     click.echo( click.style('.ds. ', fg='magenta') + s )
